@@ -44,9 +44,11 @@ class Evaluator:
         llm_ensemble: Optional[LLMEnsemble] = None,
         prompt_sampler: Optional[PromptSampler] = None,
         database: Optional[ProgramDatabase] = None,
+        suffix: Optional[str] = ".py",
     ):
         self.config = config
         self.evaluation_file = evaluation_file
+        self.program_suffix = suffix
         self.llm_ensemble = llm_ensemble
         self.prompt_sampler = prompt_sampler
         self.database = database
@@ -89,7 +91,7 @@ class Evaluator:
 
             self.evaluate_function = module.evaluate
             logger.info(f"Successfully loaded evaluation function from {self.evaluation_file}")
-            
+
             # Validate cascade configuration
             self._validate_cascade_configuration(module)
         except Exception as e:
@@ -99,16 +101,16 @@ class Evaluator:
     def _validate_cascade_configuration(self, module) -> None:
         """
         Validate cascade evaluation configuration and warn about potential issues
-        
+
         Args:
             module: The loaded evaluation module
         """
         if self.config.cascade_evaluation:
             # Check if cascade functions exist
             has_stage1 = hasattr(module, "evaluate_stage1")
-            has_stage2 = hasattr(module, "evaluate_stage2") 
+            has_stage2 = hasattr(module, "evaluate_stage2")
             has_stage3 = hasattr(module, "evaluate_stage3")
-            
+
             if not has_stage1:
                 logger.warning(
                     f"Configuration has 'cascade_evaluation: true' but evaluator "
@@ -123,7 +125,9 @@ class Evaluator:
                     f"multi-stage evaluation for better cascade benefits."
                 )
             else:
-                logger.debug(f"Cascade evaluation properly configured with available stage functions")
+                logger.debug(
+                    f"Cascade evaluation properly configured with available stage functions"
+                )
 
     async def evaluate_program(
         self,
@@ -150,7 +154,7 @@ class Evaluator:
         last_exception = None
         for attempt in range(self.config.max_retries + 1):
             # Create a temporary file for the program
-            with tempfile.NamedTemporaryFile(suffix=".py", delete=False) as temp_file:
+            with tempfile.NamedTemporaryFile(suffix=self.program_suffix, delete=False) as temp_file:
                 temp_file.write(program_code.encode("utf-8"))
                 temp_file_path = temp_file.name
 
@@ -187,8 +191,27 @@ class Evaluator:
                     llm_eval_result = self._process_evaluation_result(llm_result)
 
                     # Combine metrics
+                    llm_scores = []
                     for name, value in llm_result.metrics.items():
-                        eval_result.metrics[f"llm_{name}"] = value * self.config.llm_feedback_weight
+                        weighted_value = value * self.config.llm_feedback_weight
+                        eval_result.metrics[f"llm_{name}"] = weighted_value
+                        llm_scores.append(value)  # Use unweighted value for average
+
+                    # Add average of LLM metrics
+                    if llm_scores:
+                        llm_average = sum(llm_scores) / len(llm_scores)
+                        eval_result.metrics["llm_average"] = (
+                            llm_average * self.config.llm_feedback_weight
+                        )
+
+                        # Recalculate combined_score if it exists
+                        if "combined_score" in eval_result.metrics:
+                            # Original combined_score is just accuracy
+                            accuracy = eval_result.metrics["combined_score"]
+                            # Combine with LLM average (70% accuracy, 30% LLM quality)
+                            eval_result.metrics["combined_score"] = (
+                                accuracy * 0.7 + llm_average * 0.3
+                            )
 
                 # Store artifacts if enabled and present
                 if (
@@ -305,7 +328,9 @@ class Evaluator:
         """
         return self._pending_artifacts.pop(program_id, None)
 
-    async def _direct_evaluate(self, program_path: str) -> Union[Dict[str, float], EvaluationResult]:
+    async def _direct_evaluate(
+        self, program_path: str
+    ) -> Union[Dict[str, float], EvaluationResult]:
         """
         Directly evaluate a program using the evaluation function with timeout
 
@@ -538,8 +563,11 @@ class Evaluator:
 
         try:
             # Create prompt for LLM
+            feature_dimensions = self.database.config.feature_dimensions if self.database else []
             prompt = self.prompt_sampler.build_prompt(
-                current_program=program_code, template_key="evaluation"
+                current_program=program_code,
+                template_key="evaluation",
+                feature_dimensions=feature_dimensions,
             )
 
             # Get LLM response
@@ -616,22 +644,23 @@ class Evaluator:
     def _create_cascade_error_context(self, stage: str, error: Exception) -> dict:
         """
         Create rich error context for cascade failures
-        
+
         Args:
             stage: The stage where the error occurred
             error: The exception that was raised
-            
+
         Returns:
             Dictionary with enhanced error context
         """
         import time
+
         return {
             "failure_stage": stage,
             "error_type": type(error).__name__,
             "error_message": str(error),
             "timestamp": time.time(),
             "cascade_config": self.config.cascade_evaluation,
-            "cascade_thresholds": getattr(self.config, 'cascade_thresholds', []),
+            "cascade_thresholds": getattr(self.config, "cascade_thresholds", []),
             "timeout_config": self.config.timeout,
             "evaluation_file": self.evaluation_file,
         }
@@ -640,6 +669,9 @@ class Evaluator:
         """
         Check if metrics pass a threshold
 
+        Uses 'combined_score' if available (for consistency with evolution),
+        otherwise falls back to averaging all numeric metrics except 'error'
+
         Args:
             metrics: Dictionary of metric name to score
             threshold: Threshold to pass
@@ -650,7 +682,14 @@ class Evaluator:
         if not metrics:
             return False
 
-        # Calculate average score, skipping non-numeric values and 'error' key
+        # Use combined_score if available - this is what evolution uses
+        if "combined_score" in metrics:
+            score = metrics.get("combined_score")
+            if isinstance(score, (int, float)):
+                return float(score) >= threshold
+
+        # Fallback: average all numeric metrics except 'error'
+        # This maintains backward compatibility
         valid_metrics = []
         for name, value in metrics.items():
             # Skip 'error' keys and ensure values are numeric
